@@ -3,7 +3,10 @@ import json
 import os
 import warnings
 from dataclasses import dataclass
-from typing import Optional, Union
+from typing import List, Optional, TYPE_CHECKING, Union
+
+if TYPE_CHECKING:
+    import pandas as pd
 
 import numpy as np
 
@@ -109,12 +112,18 @@ class ColumnInfo:
     def from_dtype(cls, dtype, varlen_types=()):
         from pandas.api import types as pd_types
 
+        if (type(dtype) == str and dtype == "ascii") or (
+            type(dtype) == np.dtype and str(dtype) == "ascii"
+        ):
+            return cls("ascii", var=True)
+
         dtype = pd_types.pandas_dtype(dtype)
         # Note: be careful if you rearrange the order of the following checks
 
         # extension types
         if pd_types.is_extension_array_dtype(dtype):
-            if pd_types.is_bool_dtype(dtype):
+            if tiledb.libtiledb.version() < (2, 10) and pd_types.is_bool_dtype(dtype):
+                # as of libtiledb 2.10, we support TILEDB_BOOL
                 np_type = np.uint8
             else:
                 # XXX Parametrized dtypes such as "foo[int32]") sometimes have a "subtype"
@@ -135,7 +144,9 @@ class ColumnInfo:
 
         # bool type
         if pd_types.is_bool_dtype(dtype):
-            return cls(np.dtype("uint8"), repr="bool")
+            # as of libtiledb 2.10, we support TILEDB_BOOL
+            dtype = "uint8" if tiledb.libtiledb.version() < (2, 10) else "bool"
+            return cls(np.dtype(dtype), repr="bool")
 
         # complex types
         if pd_types.is_complex_dtype(dtype):
@@ -179,14 +190,14 @@ def _get_column_infos(df, column_types, varlen_types):
 
 def _get_schema_filters(filters):
     if filters is True:
-        # default case, unspecified: use libtiledb defaults
-        return None
+        # default case, use ZstdFilter
+        return tiledb.FilterList([tiledb.ZstdFilter()])
     elif filters is None:
         # empty filter list (schema uses zstd by default if unspecified)
         return tiledb.FilterList()
     elif isinstance(filters, (list, tiledb.FilterList)):
         return tiledb.FilterList(filters)
-    elif isinstance(filters, tiledb.libtiledb.Filter):
+    elif isinstance(filters, tiledb.Filter):
         return tiledb.FilterList([filters])
     else:
         raise ValueError("Unknown FilterList type!")
@@ -386,7 +397,7 @@ def _df_to_np_arrays(df, column_infos, fillna):
     return ret, nullmaps
 
 
-def from_pandas(uri, dataframe, **kwargs):
+def from_pandas(uri: str, dataframe: "pd.DataFrame", **kwargs):
     """Create TileDB array at given URI from a Pandas dataframe
 
     Supports most Pandas series types, including nullable integers and
@@ -394,24 +405,24 @@ def from_pandas(uri, dataframe, **kwargs):
 
     :param uri: URI for new TileDB array
     :param dataframe: pandas DataFrame
-    :param mode: Creation mode, one of 'ingest' (default), 'schema_only', 'append'
 
     :Keyword Arguments:
 
         * Any `pandas.read_csv <https://pandas.pydata.org/docs/reference/api/pandas.read_csv.html>`_ supported keyword argument
         * **ctx** - A TileDB context
         * **sparse** - (default True) Create sparse schema
-        * **index_dims** - Set the df index using a list of existing column names
+        * **chunksize** - (default None) Maximum number of rows to read at a time. Note that this is also a `pandas.read_csv` argument
+                          which `tiledb.read_csv` checks for in order to correctly read a file batchwise.
+        * **index_dims** (``List[str]``) -- List of column name(s) to use as dimension(s) in TileDB array schema. This is the recommended way to create dimensions.
         * **allows_duplicates** - Generated schema should allow duplicates
-        * **mode** - (default ``ingest``), Ingestion mode: ``ingest``, ``schema_only``, ``append``
+        * **mode** - Creation mode, one of 'ingest' (default), 'schema_only', 'append'
         * **attr_filters** - FilterList to apply to Attributes: FilterList or Dict[str -> FilterList] for any attribute(s). Unspecified attributes will use default.
         * **dim_filters** - FilterList to apply to Dimensions: FilterList or Dict[str -> FilterList] for any dimensions(s). Unspecified dimensions will use default.
-        * **coords_filters** - FilterList to apply to all coordinates (Dimensions)
         * **offsets_filters** - FilterList to apply to all offsets
         * **full_domain** - Dimensions should be created with full range of the dtype
         * **tile** - Dimension tiling: accepts either an int that applies the tiling to all dimensions or a dict("dim_name": int) to specifically assign tiling to a given dimension
         * **row_start_idx** - Start index to start new write (for row-indexed ingestions).
-        * **fillna** - Value to use to to fill holes
+        * **fillna** - Value to use to fill holes
         * **column_types** - Dictionary of {``column_name``: dtype} to apply dtypes to columns
         * **varlen_types** - A set of {dtypes}; any column wihin the set is converted to a variable length attribute
         * **capacity** - Schema capacity.
@@ -431,7 +442,11 @@ def from_pandas(uri, dataframe, **kwargs):
     else:
         tiledb_args = parse_tiledb_kwargs(kwargs)
 
-    with tiledb.scope_ctx(tiledb_args.get("ctx")):
+    ctx = tiledb_args.get("ctx")
+    if ctx is not None and not isinstance(ctx, tiledb.Ctx):
+        raise ValueError(f"`ctx` expected a TileDB Context object but saw {type(ctx)}")
+
+    with tiledb.scope_ctx(ctx):
         _from_pandas(uri, dataframe, tiledb_args)
 
 
@@ -441,7 +456,7 @@ def _from_pandas(uri, dataframe, tiledb_args):
     mode = tiledb_args.get("mode", "ingest")
 
     if mode != "append" and tiledb.array_exists(uri):
-        raise TileDBError("Array URI '{}' already exists!".format(uri))
+        raise TileDBError(f"Array URI '{uri}' already exists!")
 
     sparse = tiledb_args["sparse"]
     index_dims = tiledb_args.get("index_dims") or ()
@@ -460,7 +475,7 @@ def _from_pandas(uri, dataframe, tiledb_args):
                     "Cannot append to dense array without 'row_start_idx'"
                 )
         elif mode != "ingest":
-            raise TileDBError("Invalid mode specified ('{}')".format(mode))
+            raise TileDBError(f"Invalid mode specified ('{mode}')")
 
     # TODO: disentangle the full_domain logic
     full_domain = tiledb_args.get("full_domain", False)
@@ -485,15 +500,17 @@ def _from_pandas(uri, dataframe, tiledb_args):
 
     with tiledb.scope_ctx(tiledb_args.get("ctx")):
         if create_array:
-            _create_array(
-                uri,
-                dataframe,
-                sparse,
-                full_domain,
-                index_dims,
-                column_infos,
-                tiledb_args,
-            )
+            with warnings.catch_warnings() as w:
+                warnings.simplefilter("always")
+                _create_array(
+                    uri,
+                    dataframe,
+                    sparse,
+                    full_domain,
+                    index_dims,
+                    column_infos,
+                    tiledb_args,
+                )
 
         if write:
             if tiledb_args.get("debug", True):
@@ -531,19 +548,26 @@ def _create_array(uri, df, sparse, full_domain, index_dims, column_infos, tiledb
     )
 
     # create the ArraySchema
-    schema = tiledb.ArraySchema(
-        sparse=sparse,
-        domain=tiledb.Domain(*dims),
-        attrs=attrs,
-        cell_order=tiledb_args["cell_order"],
-        tile_order=tiledb_args["tile_order"],
-        coords_filters=_get_schema_filters(tiledb_args.get("coords_filters", True)),
-        offsets_filters=_get_schema_filters(tiledb_args.get("offsets_filters", True)),
-        # 0 will use the libtiledb internal default
-        capacity=tiledb_args.get("capacity") or 0,
-        # don't set allows_duplicates=True for dense
-        allows_duplicates=sparse and tiledb_args.get("allows_duplicates", False),
-    )
+    with warnings.catch_warnings() as w:
+        warnings.simplefilter("always")
+        coord_filter = tiledb_args.get("coords_filters", True)
+        schema = tiledb.ArraySchema(
+            sparse=sparse,
+            domain=tiledb.Domain(*dims),
+            attrs=attrs,
+            cell_order=tiledb_args["cell_order"],
+            tile_order=tiledb_args["tile_order"],
+            coords_filters=None
+            if coord_filter is True
+            else _get_schema_filters(coord_filter),
+            offsets_filters=_get_schema_filters(
+                tiledb_args.get("offsets_filters", True)
+            ),
+            # 0 will use the libtiledb internal default
+            capacity=tiledb_args.get("capacity") or 0,
+            # don't set allows_duplicates=True for dense
+            allows_duplicates=sparse and tiledb_args.get("allows_duplicates", False),
+        )
 
     tiledb.Array.create(uri, schema)
 
@@ -656,7 +680,7 @@ def _iterate_csvs_pandas(csv_list, pandas_args):
             yield result_list
 
 
-def from_csv(uri, csv_file, **kwargs):
+def from_csv(uri: str, csv_file: Union[str, List[str]], **kwargs):
     """
     Create TileDB array at given URI from a CSV file or list of files
 
@@ -669,17 +693,16 @@ def from_csv(uri, csv_file, **kwargs):
         * Any `pandas.read_csv <https://pandas.pydata.org/docs/reference/api/pandas.read_csv.html>`_ supported keyword argument
         * **ctx** - A TileDB context
         * **sparse** - (default True) Create sparse schema
-        * **index_dims** - Set the df index using a list of existing column names
+        * **index_dims** (``List[str]``) -- List of column name(s) to use as dimension(s) in TileDB array schema. This is the recommended way to create dimensions. (note: the Pandas ``read_csv`` argument ``index_col`` will be passed through if provided, which results in indexes that will be converted to dimnesions by default; however ``index_dims`` is preferred).
         * **allows_duplicates** - Generated schema should allow duplicates
-        * **mode** - (default ``ingest``), Ingestion mode: ``ingest``, ``schema_only``, ``append``
+        * **mode** - Creation mode, one of 'ingest' (default), 'schema_only', 'append'
         * **attr_filters** - FilterList to apply to Attributes: FilterList or Dict[str -> FilterList] for any attribute(s). Unspecified attributes will use default.
         * **dim_filters** - FilterList to apply to Dimensions: FilterList or Dict[str -> FilterList] for any dimensions(s). Unspecified dimensions will use default.
-        * **coords_filters** - FilterList to apply to all coordinates (Dimensions)
         * **offsets_filters** - FilterList to apply to all offsets
         * **full_domain** - Dimensions should be created with full range of the dtype
         * **tile** - Dimension tiling: accepts either an int that applies the tiling to all dimensions or a dict("dim_name": int) to specifically assign tiling to a given dimension
         * **row_start_idx** - Start index to start new write (for row-indexed ingestions).
-        * **fillna** - Value to use to to fill holes
+        * **fillna** - Value to use to fill holes
         * **column_types** - Dictionary of {``column_name``: dtype} to apply dtypes to columns
         * **varlen_types** - A set of {dtypes}; any column wihin the set is converted to a variable length attribute
         * **capacity** - Schema capacity.
@@ -711,9 +734,13 @@ def from_csv(uri, csv_file, **kwargs):
     ##########################################################################
     # set up common arguments
     ##########################################################################
+    ctx = tiledb_args.get("ctx")
+    if ctx is not None and not isinstance(ctx, tiledb.Ctx):
+        raise ValueError(f"`ctx` expected a TileDB Context object but saw {type(ctx)}")
+
     if isinstance(csv_file, str) and not os.path.isfile(csv_file):
         # for non-local files, use TileDB VFS i/o
-        vfs = tiledb.VFS(ctx=tiledb_args.get("ctx"))
+        vfs = tiledb.VFS(ctx=ctx)
         csv_file = tiledb.FileIO(vfs, csv_file, mode="rb")
     elif isinstance(csv_file, (list, tuple)):
         # TODO may be useful to support a filter callback here
